@@ -50,7 +50,7 @@ class Clock():
             self.textwriter = CairoTextWriter(self.text_scaling, self.font_name, self.fill)
 
     def calculate_text_width(self, text, font_size = 45):
-        return self.textwriter.calculate_text_width(text, font_size)
+        return self.textwriter.calculate_text_width(text, font_size * self.text_scaling)
 
     def draw(self):
         self.time = datetime.today()
@@ -103,7 +103,7 @@ class Clock():
         print "Implement draw_clock."
 
     def draw_text(self, text, font_size = 45, x = 0, y = 35):
-        self.textwriter.draw_text(text, font_size, x, y)
+        self.textwriter.draw_text(text, font_size * self.text_scaling, x, y)
 
 # The following method is currently only a placeholder/reminder 
 # and should not be used...
